m4rie: Arithmetic with dense matrices over GF(2^e)
==================================================

Description
-----------

M4RIE: Library for matrix multiplication, reduction and inversion over
GF(2^k) for 2 <= k <= 10.

License
-------

-  GNU General Public License Version 2 or later (see src/COPYING)


Upstream Contact
----------------

-  Authors: Martin Albrecht
-  Email: <m4ri-devel@googlegroups.com>
-  Website: http://m4ri.sagemath.org

Dependencies
------------

-  M4RI
-  Givaro
